==> monodevelop_1.0+dfsg.orig.tar.gz: monodevelop-1.0+dfsg/src/addins/MonoDevelop.DesignerSupport/MonoDevelop.DesignerSupport/ErrorInFileException.cs <==
// 
// ErrorInFileException.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using MonoDevelop.Projects.Parser;

namespace MonoDevelop.DesignerSupport
{
	
	public class ErrorInFileException : Exception
	{
		int line = 0;
		int column = 0;
		string fileName = null;
		
		public ErrorInFileException (IRegion region)
		{
			if (region != null) {
				line = region.BeginLine;
				column = region.BeginColumn;
				fileName = region.FileName;
			}
		}
		
		public ErrorInFileException (string fileName, int line, int column)
		{
			this.line = line;
			this.column = column;
			this.fileName = fileName;
		}
		
		public int Line {
			get { return line; }
			set { line = value; }
		}

		public int Column {
			get { return column; }
			set { column = value; }
		}

		public string FileName {
			get { return fileName; }
			set { fileName = value; }
		}
		
		public override string ToString ()
		{
			return MonoDevelop.Core.GettextCatalog.GetString ("Error in file '{0}' at line {1}, column {2}.", fileName, line, column);
		}
	}
}

==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/addins/MonoDevelop.DesignerSupport/MonoDevelop.DesignerSupport/ErrorInFileException.cs <==
// 
// ErrorInFileException.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

using MonoDevelop.Projects.Dom;

namespace MonoDevelop.DesignerSupport
{
	
	public class ErrorInFileException : Exception
	{
		int line = 0;
		int column = 0;
		string fileName = null;
		
		public ErrorInFileException (DomRegion region, string fileName)
		{
			this.line = region.Start.Line;
			this.column = region.Start.Column;
			this.fileName = fileName;
		}
		
		public ErrorInFileException (string fileName, int line, int column)
		{
			this.line = line;
			this.column = column;
			this.fileName = fileName;
		}
		
		public int Line {
			get { return line; }
			set { line = value; }
		}

		public int Column {
			get { return column; }
			set { column = value; }
		}

		public string FileName {
			get { return fileName; }
			set { fileName = value; }
		}
		
		public override string ToString ()
		{
			return MonoDevelop.Core.GettextCatalog.GetString ("Error in file '{0}' at line {1}, column {2}.", fileName, line, column);
		}
	}
}
